@@ -76,7 +76,7 @@ class Parser:
 
     #endregion methods
 
-    def get_scraper(self, config: Config, user_dir: str=None, headless: bool=True, disable_javascript: bool=False, window: dict={}, proxy_address: str=None) -> Scraper:
+    def get_scraper(self, config: Config, user_dir: str=None, headless: bool=True, fullscreen: bool=False, disable_javascript: bool=False, window: dict={}, proxy_address: str=None) -> Scraper:
         scraper_type = self.config.get('PROJECT', 'scraper')
         if scraper_type is not None:
             module_name = self.config.get('PROJECT', 'scraper')
@@ -85,4 +85,4 @@ class Parser:
             module_name = 'selenium'
             class_name = 'Selenium'
 
-        return Utils.instantiate(module_name=f'scrapeanything.scraper.scrapers.{module_name}', class_name=class_name, args={ 'headless': headless, 'disable_javascript': disable_javascript, 'window': window, 'config': config, 'user_dir': user_dir, 'proxy_address': proxy_address })
\ No newline at end of file
+        return Utils.instantiate(module_name=f'scrapeanything.scraper.scrapers.{module_name}', class_name=class_name, args={ 'headless': headless, 'fullscreen': fullscreen, 'disable_javascript': disable_javascript, 'window': window, 'config': config, 'user_dir': user_dir, 'proxy_address': proxy_address })
\ No newline at end of file
